@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 try:
     from dask.array import backends, fft, lib, linalg, ma, overlap, random
     from dask.array.blockwise import atop, blockwise
@@ -158,6 +160,7 @@ try:
     )
     from dask.array.tiledb_io import from_tiledb, to_tiledb
     from dask.array.ufunc import (
+        abs,
         absolute,
         add,
         angle,
@@ -211,6 +214,7 @@ try:
         isposinf,
         isreal,
         ldexp,
+        left_shift,
         less,
         less_equal,
         log,
@@ -232,12 +236,14 @@ try:
         negative,
         nextafter,
         not_equal,
+        positive,
         power,
         rad2deg,
         radians,
         real,
         reciprocal,
         remainder,
+        right_shift,
         rint,
         sign,
         signbit,
