@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 import itertools
 import sys
@@ -13,6 +15,7 @@ from dask.delayed import delayed
 np = pytest.importorskip("numpy")
 
 import dask.array as da
+from dask.array.numpy_compat import _numpy_123
 from dask.array.utils import assert_eq, same_keys
 
 
@@ -63,7 +66,7 @@ def test_atleast_nd_no_args(funcname):
     ],
 )
 def test_atleast_nd_one_arg(funcname, shape, chunks):
-    np_a = np.random.random(shape)
+    np_a = np.random.default_rng().random(shape)
     da_a = da.from_array(np_a, chunks=chunks)
 
     np_func = getattr(np, funcname)
@@ -85,10 +88,10 @@ def test_atleast_nd_one_arg(funcname, shape, chunks):
     ),
 )
 def test_atleast_nd_two_args(funcname, shape1, shape2):
-    np_a_1 = np.random.random(shape1)
+    np_a_1 = np.random.default_rng().random(shape1)
     da_a_1 = da.from_array(np_a_1, chunks=tuple(c // 2 for c in shape1))
 
-    np_a_2 = np.random.random(shape2)
+    np_a_2 = np.random.default_rng().random(shape2)
     da_a_2 = da.from_array(np_a_2, chunks=tuple(c // 2 for c in shape2))
 
     np_a_n = [np_a_1, np_a_2]
@@ -139,7 +142,7 @@ def test_transpose_skip_when_possible():
 
 
 def test_swapaxes():
-    x = np.random.normal(0, 10, size=(10, 12, 7))
+    x = np.random.default_rng().normal(0, 10, size=(10, 12, 7))
     d = da.from_array(x, chunks=(4, 5, 2))
 
     assert_eq(np.swapaxes(x, 0, 1), da.swapaxes(d, 0, 1))
@@ -157,7 +160,7 @@ def test_swapaxes():
 @pytest.mark.parametrize("funcname", ["moveaxis", "rollaxis"])
 @pytest.mark.parametrize("shape", [(), (5,), (3, 5, 7, 3)])
 def test_moveaxis_rollaxis(funcname, shape):
-    x = np.random.random(shape)
+    x = np.random.default_rng().random(shape)
     d = da.from_array(x, chunks=(len(shape) * (2,)))
     np_func = getattr(np, funcname)
     da_func = getattr(da, funcname)
@@ -168,7 +171,7 @@ def test_moveaxis_rollaxis(funcname, shape):
 
 
 def test_moveaxis_rollaxis_keyword():
-    x = np.random.random((10, 12, 7))
+    x = np.random.default_rng().random((10, 12, 7))
     d = da.from_array(x, chunks=(4, 5, 2))
     assert_eq(
         np.moveaxis(x, destination=1, source=0), da.moveaxis(d, destination=1, source=0)
@@ -179,7 +182,7 @@ def test_moveaxis_rollaxis_keyword():
 
 
 def test_moveaxis_rollaxis_numpy_api():
-    a = da.random.random((4, 4, 4), chunks=2)
+    a = da.random.default_rng().random((4, 4, 4), chunks=2)
     result = np.moveaxis(a, 2, 0)
     assert isinstance(result, da.Array)
     assert_eq(result, np.moveaxis(a.compute(), 2, 0))
@@ -215,7 +218,7 @@ def test_flip(funcname, kwargs, shape):
     elif not isinstance(axis, tuple):
         axis = (axis,)
 
-    np_a = np.random.random(shape)
+    np_a = np.random.default_rng().random(shape)
     da_a = da.from_array(np_a, chunks=1)
 
     np_func = getattr(np, funcname)
@@ -241,11 +244,11 @@ def test_flip(funcname, kwargs, shape):
 @pytest.mark.parametrize("shape", [tuple(), (4,), (4, 6), (4, 6, 8), (4, 6, 8, 10)])
 def test_rot90(kwargs, shape):
     axes = kwargs.get("axes", (0, 1))
-    np_a = np.random.random(shape)
+    np_a = np.random.default_rng().random(shape)
     da_a = da.from_array(np_a, chunks=1)
 
-    np_func = getattr(np, "rot90")
-    da_func = getattr(da, "rot90")
+    np_func = np.rot90
+    da_func = da.rot90
 
     try:
         for axis in axes[:2]:
@@ -303,10 +306,10 @@ def test_rot90(kwargs, shape):
     ],
 )
 def test_matmul(x_shape, y_shape, x_chunks, y_chunks):
-    np.random.seed(3732)
+    rng = np.random.default_rng(3732)
 
-    x = np.random.random(x_shape)[()]
-    y = np.random.random(y_shape)[()]
+    x = rng.random(x_shape)[()]
+    y = rng.random(y_shape)[()]
 
     a = da.from_array(x, chunks=x_chunks or tuple((i // 2) for i in x.shape))
     b = da.from_array(y, chunks=y_chunks or tuple((i // 2) for i in y.shape))
@@ -396,7 +399,7 @@ def test_dot_method():
 
 def test_dot_persist_equivalence():
     # Regression test for https://github.com/dask/dask/issues/6907
-    x = da.random.random((4, 4), chunks=(2, 2))
+    x = da.random.default_rng().random((4, 4), chunks=(2, 2))
     x[x < 0.65] = 0
     y = x.persist()
     z = x.compute()
@@ -409,12 +412,12 @@ def test_dot_persist_equivalence():
 
 @pytest.mark.parametrize("shape, chunks", [((20,), (6,)), ((4, 5), (2, 3))])
 def test_vdot(shape, chunks):
-    np.random.seed(1337)
+    rng = np.random.default_rng(1337)
 
-    x = 2 * np.random.random((2,) + shape) - 1
+    x = 2 * rng.random((2,) + shape) - 1
     x = x[0] + 1j * x[1]
 
-    y = 2 * np.random.random((2,) + shape) - 1
+    y = 2 * rng.random((2,) + shape) - 1
     y = y[0] + 1j * y[1]
 
     a = da.from_array(x, chunks=chunks)
@@ -427,10 +430,10 @@ def test_vdot(shape, chunks):
 
 @pytest.mark.parametrize("shape1, shape2", [((20,), (6,)), ((4, 5), (2, 3))])
 def test_outer(shape1, shape2):
-    np.random.seed(1337)
+    rng = np.random.default_rng(1337)
 
-    x = 2 * np.random.random(shape1) - 1
-    y = 2 * np.random.random(shape2) - 1
+    x = 2 * rng.random(shape1) - 1
+    y = 2 * rng.random(shape2) - 1
 
     a = da.from_array(x, chunks=3)
     b = da.from_array(y, chunks=3)
@@ -454,7 +457,7 @@ def test_outer(shape1, shape2):
     [[(10, 15, 20), 0], [(10, 15, 20), 1], [(10, 15, 20), 2], [(10, 15, 20), -1]],
 )
 def test_apply_along_axis(func1d_name, func1d, specify_output_props, input_shape, axis):
-    a = np.random.randint(0, 10, input_shape)
+    a = np.random.default_rng().integers(0, 10, input_shape)
     d = da.from_array(a, chunks=(len(input_shape) * (5,)))
 
     output_shape = None
@@ -499,7 +502,7 @@ def test_apply_along_axis(func1d_name, func1d, specify_output_props, input_shape
     ],
 )
 def test_apply_over_axes(func_name, func, shape, axes):
-    a = np.random.randint(0, 10, shape)
+    a = np.random.default_rng().integers(0, 10, shape)
     d = da.from_array(a, chunks=(len(shape) * (5,)))
 
     assert_eq(da.apply_over_axes(func, d, axes), np.apply_over_axes(func, a, axes))
@@ -516,7 +519,7 @@ def test_apply_over_axes(func_name, func, shape, axes):
     ],
 )
 def test_ptp(shape, axis):
-    a = np.random.randint(0, 10, shape)
+    a = np.random.default_rng().integers(0, 10, shape)
     d = da.from_array(a, chunks=(len(shape) * (5,)))
 
     assert_eq(da.ptp(d, axis), np.ptp(a, axis))
@@ -528,7 +531,7 @@ def test_ptp(shape, axis):
 )
 @pytest.mark.parametrize("n", [0, 1, 2])
 def test_diff(shape, n, axis):
-    x = np.random.randint(0, 10, shape)
+    x = np.random.default_rng().integers(0, 10, shape)
     a = da.from_array(x, chunks=(len(shape) * (5,)))
 
     assert_eq(da.diff(a, n, axis), np.diff(x, n, axis))
@@ -598,7 +601,7 @@ def test_diff_negative_order():
 @pytest.mark.parametrize("shape", [(10,), (10, 15)])
 @pytest.mark.parametrize("to_end, to_begin", [[None, None], [0, 0], [[1, 2], [3, 4]]])
 def test_ediff1d(shape, to_end, to_begin):
-    x = np.random.randint(0, 10, shape)
+    x = np.random.default_rng().integers(0, 10, shape)
     a = da.from_array(x, chunks=(len(shape) * (5,)))
 
     assert_eq(da.ediff1d(a, to_end, to_begin), np.ediff1d(x, to_end, to_begin))
@@ -622,7 +625,7 @@ def test_ediff1d(shape, to_end, to_begin):
 )
 @pytest.mark.parametrize("edge_order", [1, 2])
 def test_gradient(shape, varargs, axis, edge_order):
-    a = np.random.randint(0, 10, shape)
+    a = np.random.default_rng().integers(0, 10, shape)
     d_a = da.from_array(a, chunks=(len(shape) * (5,)))
 
     r_a = np.gradient(a, *varargs, axis=axis, edge_order=edge_order)
@@ -693,8 +696,8 @@ def test_digitize():
                 da.digitize(d, bins, right=right), np.digitize(x, bins, right=right)
             )
 
-    x = np.random.random(size=(100, 100))
-    bins = np.random.random(size=13)
+    x = np.random.default_rng().random(size=(100, 100))
+    bins = np.random.default_rng().random(size=13)
     bins.sort()
     for chunks in [(10, 10), (10, 20), (13, 17), (87, 54)]:
         for right in [False, True]:
@@ -738,7 +741,7 @@ def test_searchsorted_sorter_not_implemented():
 def test_histogram():
     # Test for normal, flattened input
     n = 100
-    v = da.random.random(n, chunks=10)
+    v = da.random.default_rng().random(n, chunks=10)
     bins = np.arange(0, 1.01, 0.01)
     (a1, b1) = da.histogram(v, bins=bins)
     (a2, b2) = np.histogram(v, bins=bins)
@@ -751,7 +754,7 @@ def test_histogram():
 
 
 def test_histogram_alternative_bins_range():
-    v = da.random.random(100, chunks=10)
+    v = da.random.default_rng().random(100, chunks=10)
     (a1, b1) = da.histogram(v, bins=10, range=(0, 1))
     (a2, b2) = np.histogram(v, bins=10, range=(0, 1))
     assert_eq(a1, a2)
@@ -768,7 +771,7 @@ def test_histogram_bins_range_with_nan_array():
 
 
 def test_histogram_return_type():
-    v = da.random.random(100, chunks=10)
+    v = da.random.default_rng().random(100, chunks=10)
     bins = np.arange(0, 1.01, 0.01)
     # Check if return type is same as hist
     bins = np.arange(0, 11, 1, dtype="i4")
@@ -778,10 +781,14 @@ def test_histogram_return_type():
 def test_histogram_extra_args_and_shapes():
     # Check for extra args and shapes
     bins = np.arange(0, 1.01, 0.01)
-    v = da.random.random(100, chunks=10)
+    v = da.random.default_rng().random(100, chunks=10)
     data = [
         (v, bins, da.ones(100, chunks=v.chunks) * 5),
-        (da.random.random((50, 50), chunks=10), bins, da.ones((50, 50), chunks=10) * 5),
+        (
+            da.random.default_rng().random((50, 50), chunks=10),
+            bins,
+            da.ones((50, 50), chunks=10) * 5,
+        ),
     ]
 
     for v, bins, w in data:
@@ -829,7 +836,7 @@ def test_histogram_normed_deprecation():
     ],
 )
 def test_histogram_bin_range_raises(bins, hist_range):
-    data = da.random.random(10, chunks=2)
+    data = da.random.default_rng().random(10, chunks=2)
     with pytest.raises((ValueError, TypeError)) as info:
         da.histogram(data, bins=bins, range=hist_range)
     err_msg = str(info.value)
@@ -842,11 +849,11 @@ def test_histogram_bin_range_raises(bins, hist_range):
 @pytest.mark.parametrize("delay_n_bins", [False, True])
 def test_histogram_delayed_range(density, weighted, non_delayed_i, delay_n_bins):
     n = 100
-    v = np.random.random(n)
+    v = np.random.default_rng().random(n)
     vd = da.from_array(v, chunks=10)
 
     if weighted:
-        weights = np.random.random(n)
+        weights = np.random.default_rng().random(n)
         weights_d = da.from_array(weights, chunks=vd.chunks)
 
     d_range = [vd.min(), vd.max()]
@@ -876,14 +883,14 @@ def test_histogram_delayed_range(density, weighted, non_delayed_i, delay_n_bins)
 @pytest.mark.parametrize("weighted", [True, False])
 def test_histogram_delayed_bins(density, weighted):
     n = 100
-    v = np.random.random(n)
+    v = np.random.default_rng().random(n)
     bins = np.array([0, 0.2, 0.5, 0.8, 1])
 
     vd = da.from_array(v, chunks=10)
     bins_d = da.from_array(bins, chunks=2)
 
     if weighted:
-        weights = np.random.random(n)
+        weights = np.random.default_rng().random(n)
         weights_d = da.from_array(weights, chunks=vd.chunks)
 
     hist_d, bins_d2 = da.histogram(
@@ -908,7 +915,7 @@ def test_histogram_delayed_bins(density, weighted):
 
 
 def test_histogram_delayed_n_bins_raises_with_density():
-    data = da.random.random(10, chunks=2)
+    data = da.random.default_rng().random(10, chunks=2)
     with pytest.raises(
         NotImplementedError, match="`bins` cannot be a scalar Dask object"
     ):
@@ -919,12 +926,13 @@ def test_histogram_delayed_n_bins_raises_with_density():
 @pytest.mark.parametrize("density", [True, False])
 @pytest.mark.parametrize("bins", [(5, 6), 5])
 def test_histogram2d(weights, density, bins):
+    rng = da.random.default_rng()
     n = 800
     b = bins
     r = ((0, 1), (0, 1))
-    x = da.random.uniform(0, 1, size=(n,), chunks=(200,))
-    y = da.random.uniform(0, 1, size=(n,), chunks=(200,))
-    w = da.random.uniform(0.2, 1.1, size=(n,), chunks=(200,)) if weights else None
+    x = rng.uniform(0, 1, size=(n,), chunks=(200,))
+    y = rng.uniform(0, 1, size=(n,), chunks=(200,))
+    w = rng.uniform(0.2, 1.1, size=(n,), chunks=(200,)) if weights else None
     a1, b1x, b1y = da.histogram2d(x, y, bins=b, range=r, density=density, weights=w)
     a2, b2x, b2y = np.histogram2d(x, y, bins=b, range=r, density=density, weights=w)
     a3, b3x, b3y = np.histogram2d(
@@ -950,13 +958,14 @@ def test_histogram2d(weights, density, bins):
 @pytest.mark.parametrize("weights", [True, False])
 @pytest.mark.parametrize("density", [True, False])
 def test_histogram2d_array_bins(weights, density):
+    rng = da.random.default_rng()
     n = 800
     xbins = [0.0, 0.2, 0.6, 0.9, 1.0]
     ybins = [0.0, 0.1, 0.4, 0.5, 1.0]
     b = [xbins, ybins]
-    x = da.random.uniform(0, 1, size=(n,), chunks=(200,))
-    y = da.random.uniform(0, 1, size=(n,), chunks=(200,))
-    w = da.random.uniform(0.2, 1.1, size=(n,), chunks=(200,)) if weights else None
+    x = rng.uniform(0, 1, size=(n,), chunks=(200,))
+    y = rng.uniform(0, 1, size=(n,), chunks=(200,))
+    w = rng.uniform(0.2, 1.1, size=(n,), chunks=(200,)) if weights else None
     a1, b1x, b1y = da.histogram2d(x, y, bins=b, density=density, weights=w)
     a2, b2x, b2y = np.histogram2d(x, y, bins=b, density=density, weights=w)
     a3, b3x, b3y = np.histogram2d(
@@ -980,7 +989,7 @@ def test_histogram2d_array_bins(weights, density):
 
 def test_histogramdd():
     n1, n2 = 800, 3
-    x = da.random.uniform(0, 1, size=(n1, n2), chunks=(200, 3))
+    x = da.random.default_rng().uniform(0, 1, size=(n1, n2), chunks=(200, 3))
     bins = [[0, 0.5, 1], [0, 0.25, 0.85, 1], [0, 0.5, 0.8, 1]]
     (a1, b1) = da.histogramdd(x, bins=bins)
     (a2, b2) = np.histogramdd(x, bins=bins)
@@ -994,9 +1003,10 @@ def test_histogramdd():
 
 
 def test_histogramdd_seq_of_arrays():
+    rng = da.random.default_rng()
     n1 = 800
-    x = da.random.uniform(size=(n1,), chunks=200)
-    y = da.random.uniform(size=(n1,), chunks=200)
+    x = rng.uniform(size=(n1,), chunks=200)
+    y = rng.uniform(size=(n1,), chunks=200)
     bx = [0.0, 0.25, 0.75, 1.0]
     by = [0.0, 0.30, 0.70, 0.8, 1.0]
     (a1, b1) = da.histogramdd([x, y], bins=[bx, by])
@@ -1009,7 +1019,9 @@ def test_histogramdd_seq_of_arrays():
 def test_histogramdd_alternative_bins_range():
     # test for normal input
     n1, n2 = 600, 3
-    x = da.random.uniform(0, 1, size=(n1, n2), chunks=((200, 200, 200), (3,)))
+    x = da.random.default_rng().uniform(
+        0, 1, size=(n1, n2), chunks=((200, 200, 200), (3,))
+    )
     bins = (3, 5, 4)
     ranges = ((0, 1),) * len(bins)
     (a1, b1) = da.histogramdd(x, bins=bins, range=ranges)
@@ -1028,10 +1040,11 @@ def test_histogramdd_alternative_bins_range():
 
 
 def test_histogramdd_weighted():
+    rng = da.random.default_rng()
     # test for normal input
     n1, n2 = 600, 3
-    x = da.random.uniform(0, 1, size=(n1, n2), chunks=((200, 200, 200), (3,)))
-    w = da.random.uniform(0.5, 0.8, size=(n1,), chunks=200)
+    x = rng.uniform(0, 1, size=(n1, n2), chunks=((200, 200, 200), (3,)))
+    w = rng.uniform(0.5, 0.8, size=(n1,), chunks=200)
     bins = (3, 5, 4)
     ranges = ((0, 1),) * len(bins)
     (a1, b1) = da.histogramdd(x, bins=bins, range=ranges, weights=w)
@@ -1049,7 +1062,7 @@ def test_histogramdd_weighted():
 
 def test_histogramdd_density():
     n1, n2 = 800, 3
-    x = da.random.uniform(0, 1, size=(n1, n2), chunks=(200, 3))
+    x = da.random.default_rng().uniform(0, 1, size=(n1, n2), chunks=(200, 3))
     bins = [[0, 0.5, 1], [0, 0.25, 0.85, 1], [0, 0.5, 0.8, 1]]
     (a1, b1) = da.histogramdd(x, bins=bins, density=True)
     (a2, b2) = np.histogramdd(x, bins=bins, density=True)
@@ -1062,9 +1075,10 @@ def test_histogramdd_density():
 
 
 def test_histogramdd_weighted_density():
+    rng = da.random.default_rng()
     n1, n2 = 1200, 4
-    x = da.random.standard_normal(size=(n1, n2), chunks=(200, 4))
-    w = da.random.uniform(0.5, 1.2, size=(n1,), chunks=200)
+    x = rng.standard_normal(size=(n1, n2), chunks=(200, 4))
+    w = rng.uniform(0.5, 1.2, size=(n1,), chunks=200)
     bins = (5, 6, 7, 8)
     ranges = ((-4, 4),) * len(bins)
     (a1, b1) = da.histogramdd(x, bins=bins, range=ranges, weights=w, density=True)
@@ -1075,7 +1089,7 @@ def test_histogramdd_weighted_density():
 
 
 def test_histogramdd_raises_incompat_sample_chunks():
-    data = da.random.random(size=(10, 3), chunks=(5, 1))
+    data = da.random.default_rng().random(size=(10, 3), chunks=(5, 1))
     with pytest.raises(
         ValueError, match="Input array can only be chunked along the 0th axis"
     ):
@@ -1083,9 +1097,10 @@ def test_histogramdd_raises_incompat_sample_chunks():
 
 
 def test_histogramdd_raises_incompat_multiarg_chunks():
-    x = da.random.random(size=(10,), chunks=2)
-    y = da.random.random(size=(10,), chunks=2)
-    z = da.random.random(size=(10,), chunks=5)
+    rng = da.random.default_rng()
+    x = rng.random(size=(10,), chunks=2)
+    y = rng.random(size=(10,), chunks=2)
+    z = rng.random(size=(10,), chunks=5)
     with pytest.raises(
         ValueError, match="All coordinate arrays must be chunked identically."
     ):
@@ -1093,10 +1108,11 @@ def test_histogramdd_raises_incompat_multiarg_chunks():
 
 
 def test_histogramdd_raises_incompat_weight_chunks():
-    x = da.random.random(size=(10,), chunks=2)
-    y = da.random.random(size=(10,), chunks=2)
+    rng = da.random.default_rng()
+    x = rng.random(size=(10,), chunks=2)
+    y = rng.random(size=(10,), chunks=2)
     z = da.atleast_2d((x, y)).T.rechunk((2, 2))
-    w = da.random.random(size=(10,), chunks=5)
+    w = rng.random(size=(10,), chunks=5)
     with pytest.raises(
         ValueError,
         match="Input arrays and weights must have the same shape and chunk structure.",
@@ -1110,7 +1126,7 @@ def test_histogramdd_raises_incompat_weight_chunks():
 
 
 def test_histogramdd_raises_incompat_bins_or_range():
-    data = da.random.random(size=(10, 4), chunks=(5, 4))
+    data = da.random.default_rng().random(size=(10, 4), chunks=(5, 4))
     bins = (2, 3, 4, 5)
     ranges = ((0, 1),) * len(bins)
 
@@ -1139,7 +1155,7 @@ def test_histogramdd_raises_incompat_bins_or_range():
 
 
 def test_histogramdd_raise_normed_and_density():
-    data = da.random.random(size=(10, 3), chunks=(5, 3))
+    data = da.random.default_rng().random(size=(10, 3), chunks=(5, 3))
     bins = (4, 5, 6)
     ranges = ((0, 1),) * 3
     with pytest.raises(TypeError, match="Cannot specify both 'normed' and 'density'"):
@@ -1148,13 +1164,13 @@ def test_histogramdd_raise_normed_and_density():
 
 def test_histogramdd_raise_incompat_shape():
     # 1D
-    data = da.random.random(size=(10,), chunks=(2,))
+    data = da.random.default_rng().random(size=(10,), chunks=(2,))
     with pytest.raises(
         ValueError, match="Single array input to histogramdd should be columnar"
     ):
         da.histogramdd(data, bins=4, range=((-3, 3),))
     # 3D (not columnar)
-    data = da.random.random(size=(4, 4, 4), chunks=(2, 2, 2))
+    data = da.random.default_rng().random(size=(4, 4, 4), chunks=(2, 2, 2))
     with pytest.raises(
         ValueError, match="Single array input to histogramdd should be columnar"
     ):
@@ -1162,7 +1178,7 @@ def test_histogramdd_raise_incompat_shape():
 
 
 def test_histogramdd_edges():
-    data = da.random.random(size=(10, 3), chunks=(5, 3))
+    data = da.random.default_rng().random(size=(10, 3), chunks=(5, 3))
     edges = [
         np.array([0.1, 0.3, 0.8, 1.0]),
         np.array([0.2, 0.3, 0.8, 0.9]),
@@ -1218,7 +1234,7 @@ def test_corrcoef():
 
 
 def test_round():
-    x = np.random.random(10)
+    x = np.random.default_rng().random(10)
     d = da.from_array(x, chunks=4)
 
     for i in (0, 1, 4, 5):
@@ -1267,9 +1283,9 @@ def test_unique_kwargs(return_index, return_inverse, return_counts):
     [[(10,), (5,)], [(10,), (3,)], [(4, 5), (3, 2)], [(20, 20), (4, 5)]],
 )
 def test_unique_rand(seed, low, high, shape, chunks):
-    np.random.seed(seed)
+    rng = np.random.default_rng(seed)
 
-    a = np.random.randint(low, high, size=shape)
+    a = rng.integers(low, high, size=shape)
     d = da.from_array(a, chunks=chunks)
 
     kwargs = dict(return_index=True, return_inverse=True, return_counts=True)
@@ -1299,12 +1315,12 @@ def test_unique_rand(seed, low, high, shape, chunks):
 def test_isin_rand(
     seed, low, high, elements_shape, elements_chunks, test_shape, test_chunks, invert
 ):
-    rng = np.random.RandomState(seed)
+    rng = np.random.default_rng(seed)
 
-    a1 = rng.randint(low, high, size=elements_shape)
+    a1 = rng.integers(low, high, size=elements_shape)
     d1 = da.from_array(a1, chunks=elements_chunks)
 
-    a2 = rng.randint(low, high, size=test_shape) - 5
+    a2 = rng.integers(low, high, size=test_shape) - 5
     d2 = da.from_array(a2, chunks=test_chunks)
 
     with warnings.catch_warnings():
@@ -1336,7 +1352,7 @@ def _maybe_len(l):
 @pytest.mark.parametrize("shift", [3, 7, 9, (3, 9), (7, 2)])
 @pytest.mark.parametrize("axis", [None, 0, 1, -1, (0, 1), (1, 0)])
 def test_roll(chunks, shift, axis):
-    x = np.random.randint(10, size=(4, 6))
+    x = np.random.default_rng().integers(10, size=(4, 6))
     a = da.from_array(x, chunks=chunks)
 
     if _maybe_len(shift) != _maybe_len(axis):
@@ -1360,10 +1376,10 @@ def test_roll_works_even_if_shape_is_0():
 
 @pytest.mark.parametrize("shape", [(10,), (5, 10), (5, 10, 10)])
 def test_shape_and_ndim(shape):
-    x = da.random.random(shape)
+    x = da.random.default_rng().random(shape)
     assert np.shape(x) == shape
 
-    x = da.random.random(shape)
+    x = da.random.default_rng().random(shape)
     assert np.ndim(x) == len(shape)
 
 
@@ -1391,7 +1407,7 @@ def test_union1d(shape, reverse):
 
 
 def test_ravel():
-    x = np.random.randint(10, size=(4, 6))
+    x = np.random.default_rng().integers(10, size=(4, 6))
 
     # 2d
     for chunks in [(4, 6), (2, 6)]:
@@ -1407,7 +1423,7 @@ def test_ravel():
     assert_eq(a_flat.ravel(), a_flat)
 
     # 3d
-    x = np.random.randint(10, size=(2, 3, 4))
+    x = np.random.default_rng().integers(10, size=(2, 3, 4))
     for chunks in [4, (1, 3, 4)]:
         a = da.from_array(x, chunks=chunks)
         assert_eq(x.ravel(), a.ravel())
@@ -1417,7 +1433,7 @@ def test_ravel():
 
 
 def test_ravel_1D_no_op():
-    x = np.random.randint(10, size=100)
+    x = np.random.default_rng().integers(10, size=100)
     dx = da.from_array(x, chunks=10)
     # known dims
     assert_eq(dx.ravel(), x.ravel())
@@ -1670,7 +1686,7 @@ def test_allclose():
 
 def test_choose():
     # test choose function
-    x = np.random.randint(10, size=(15, 16))
+    x = np.random.default_rng().integers(10, size=(15, 16))
     d = da.from_array(x, chunks=(4, 5))
 
     assert_eq(da.choose(d > 5, [0, d]), np.choose(x > 5, [0, x]))
@@ -1684,9 +1700,9 @@ def test_choose():
 
 
 def test_piecewise():
-    np.random.seed(1337)
+    rng = np.random.default_rng(1337)
 
-    x = np.random.randint(10, size=(15, 16))
+    x = rng.integers(10, size=(15, 16))
     d = da.from_array(x, chunks=(4, 5))
 
     assert_eq(
@@ -1696,9 +1712,9 @@ def test_piecewise():
 
 
 def test_piecewise_otherwise():
-    np.random.seed(1337)
+    rng = np.random.default_rng(1337)
 
-    x = np.random.randint(10, size=(15, 16))
+    x = rng.integers(10, size=(15, 16))
     d = da.from_array(x, chunks=(4, 5))
 
     assert_eq(
@@ -1736,7 +1752,7 @@ def test_select():
 
 
 def test_select_multidimension():
-    x = np.random.random((100, 50, 2))
+    x = np.random.default_rng().random((100, 50, 2))
     y = da.from_array(x, chunks=(50, 50, 1))
     res_x = np.select([x < 0, x > 2, x > 1], [x, x * 2, x * 3], default=1)
     res_y = da.select([y < 0, y > 2, y > 1], [y, y * 2, y * 3], default=1)
@@ -1765,7 +1781,7 @@ def test_select_broadcasting():
 
 def test_argwhere():
     for shape, chunks in [(0, ()), ((0, 0), (0, 0)), ((15, 16), (4, 5))]:
-        x = np.random.randint(10, size=shape)
+        x = np.random.default_rng().integers(10, size=shape)
         d = da.from_array(x, chunks=chunks)
 
         x_nz = np.argwhere(x)
@@ -1775,7 +1791,7 @@ def test_argwhere():
 
 
 def test_argwhere_obj():
-    x = np.random.randint(10, size=(15, 16)).astype(object)
+    x = np.random.default_rng().integers(10, size=(15, 16)).astype(object)
     d = da.from_array(x, chunks=(4, 5))
 
     x_nz = np.argwhere(x)
@@ -1798,10 +1814,11 @@ def test_argwhere_str():
 
 
 def test_where():
-    x = np.random.randint(10, size=(15, 14))
+    rng = np.random.default_rng()
+    x = rng.integers(10, size=(15, 14))
     x[5, 5] = x[4, 4] = 0  # Ensure some false elements
     d = da.from_array(x, chunks=(4, 5))
-    y = np.random.randint(10, size=15).astype(np.uint8)
+    y = rng.integers(10, size=15).astype(np.uint8)
     e = da.from_array(y, chunks=(4,))
 
     for c1, c2 in [
@@ -1837,9 +1854,10 @@ def test_where_scalar_dtype():
 
 
 def test_where_bool_optimization():
-    x = np.random.randint(10, size=(15, 16))
+    rng = np.random.default_rng()
+    x = rng.integers(10, size=(15, 16))
     d = da.from_array(x, chunks=(4, 5))
-    y = np.random.randint(10, size=(15, 16))
+    y = rng.integers(10, size=(15, 16))
     e = da.from_array(y, chunks=(4, 5))
 
     for c in [True, False, np.True_, np.False_, 1, 0]:
@@ -1855,7 +1873,7 @@ def test_where_bool_optimization():
 
 def test_where_nonzero():
     for shape, chunks in [(0, ()), ((0, 0), (0, 0)), ((15, 16), (4, 5))]:
-        x = np.random.randint(10, size=shape)
+        x = np.random.default_rng().integers(10, size=shape)
         d = da.from_array(x, chunks=chunks)
 
         x_w = np.where(x)
@@ -1881,7 +1899,7 @@ def test_where_incorrect_args():
 
 def test_count_nonzero():
     for shape, chunks in [(0, ()), ((0, 0), (0, 0)), ((15, 16), (4, 5))]:
-        x = np.random.randint(10, size=shape)
+        x = np.random.default_rng().integers(10, size=shape)
         d = da.from_array(x, chunks=chunks)
 
         x_c = np.count_nonzero(x)
@@ -1896,7 +1914,7 @@ def test_count_nonzero():
 @pytest.mark.parametrize("axis", [None, 0, (1,), (0, 1)])
 def test_count_nonzero_axis(axis):
     for shape, chunks in [((0, 0), (0, 0)), ((15, 16), (4, 5))]:
-        x = np.random.randint(10, size=shape)
+        x = np.random.default_rng().integers(10, size=shape)
         d = da.from_array(x, chunks=chunks)
 
         x_c = np.count_nonzero(x, axis)
@@ -1909,7 +1927,7 @@ def test_count_nonzero_axis(axis):
 
 
 def test_count_nonzero_obj():
-    x = np.random.randint(10, size=(15, 16)).astype(object)
+    x = np.random.default_rng().integers(10, size=(15, 16)).astype(object)
     d = da.from_array(x, chunks=(4, 5))
 
     x_c = np.count_nonzero(x)
@@ -1923,7 +1941,7 @@ def test_count_nonzero_obj():
 
 @pytest.mark.parametrize("axis", [None, 0, (1,), (0, 1)])
 def test_count_nonzero_obj_axis(axis):
-    x = np.random.randint(10, size=(15, 16)).astype(object)
+    x = np.random.default_rng().integers(10, size=(15, 16)).astype(object)
     d = da.from_array(x, chunks=(4, 5))
 
     x_c = np.count_nonzero(x, axis)
@@ -1955,7 +1973,7 @@ def test_count_nonzero_str():
 
 def test_flatnonzero():
     for shape, chunks in [(0, ()), ((0, 0), (0, 0)), ((15, 16), (4, 5))]:
-        x = np.random.randint(10, size=shape)
+        x = np.random.default_rng().integers(10, size=shape)
         d = da.from_array(x, chunks=chunks)
 
         x_fnz = np.flatnonzero(x)
@@ -1966,7 +1984,7 @@ def test_flatnonzero():
 
 def test_nonzero():
     for shape, chunks in [(0, ()), ((0, 0), (0, 0)), ((15, 16), (4, 5))]:
-        x = np.random.randint(10, size=shape)
+        x = np.random.default_rng().integers(10, size=shape)
         d = da.from_array(x, chunks=chunks)
 
         x_nz = np.nonzero(x)
@@ -1981,7 +1999,7 @@ def test_nonzero():
 
 def test_nonzero_method():
     for shape, chunks in [(0, ()), ((0, 0), (0, 0)), ((15, 16), (4, 5))]:
-        x = np.random.randint(10, size=shape)
+        x = np.random.default_rng().integers(10, size=shape)
         d = da.from_array(x, chunks=chunks)
 
         x_nz = x.nonzero()
@@ -2007,6 +2025,7 @@ def test_unravel_index_empty():
 
 
 def test_unravel_index():
+    rng = np.random.default_rng()
     for nindices, shape, order in [
         (0, (15,), "C"),
         (1, (15,), "C"),
@@ -2015,10 +2034,10 @@ def test_unravel_index():
         (2, (15, 16), "C"),
         (2, (15, 16), "F"),
     ]:
-        arr = np.random.random(shape)
+        arr = rng.random(shape)
         darr = da.from_array(arr, chunks=1)
 
-        findices = np.random.randint(np.prod(shape, dtype=int), size=nindices)
+        findices = rng.integers(np.prod(shape, dtype=int), size=nindices)
         d_findices = da.from_array(findices, chunks=1)
 
         indices = np.unravel_index(findices, shape, order)
@@ -2127,7 +2146,7 @@ def test_ravel_multi_index_non_int_dtype():
 
 
 def test_coarsen():
-    x = np.random.randint(10, size=(24, 24))
+    x = np.random.default_rng().integers(10, size=(24, 24))
     d = da.from_array(x, chunks=(4, 8))
 
     assert_eq(
@@ -2177,7 +2196,6 @@ def test_coarsen_bad_chunks(chunks):
     ],
 )
 def test_aligned_coarsen_chunks(chunks, divisor):
-
     from dask.array.routines import aligned_coarsen_chunks as acc
 
     aligned_chunks = acc(chunks, divisor)
@@ -2202,9 +2220,10 @@ def test_aligned_coarsen_chunks(chunks, divisor):
 
 
 def test_insert():
-    x = np.random.randint(10, size=(10, 10))
+    rng = np.random.default_rng()
+    x = rng.integers(10, size=(10, 10))
     a = da.from_array(x, chunks=(5, 5))
-    y = np.random.randint(10, size=(5, 10))
+    y = rng.integers(10, size=(5, 10))
     b = da.from_array(y, chunks=(4, 4))
 
     assert_eq(np.insert(x, 0, -1, axis=0), da.insert(a, 0, -1, axis=0))
@@ -2241,15 +2260,16 @@ def test_insert():
 
 
 def test_append():
-    x = np.random.randint(10, size=(10, 10))
+    rng = np.random.default_rng()
+    x = rng.integers(10, size=(10, 10))
     a = da.from_array(x, chunks=(5, 5))
 
     # appendage for axis 1 / -1
-    y1 = np.random.randint(10, size=(10, 5))
+    y1 = rng.integers(10, size=(10, 5))
     b1 = da.from_array(y1, chunks=(4, 4))
 
     # appendage for axis 0 / -2
-    y0 = np.random.randint(10, size=(5, 10))
+    y0 = rng.integers(10, size=(5, 10))
     b0 = da.from_array(y0, chunks=(4, 4))
 
     # test axis None
@@ -2289,7 +2309,7 @@ def test_append():
 
 
 def test_multi_insert():
-    z = np.random.randint(10, size=(1, 2))
+    z = np.random.default_rng().integers(10, size=(1, 2))
     c = da.from_array(z, chunks=(1, 2))
     assert_eq(
         np.insert(np.insert(z, [0, 1], -1, axis=0), [1], -1, axis=1),
@@ -2298,7 +2318,7 @@ def test_multi_insert():
 
 
 def test_delete():
-    x = np.random.randint(10, size=(10, 10))
+    x = np.random.default_rng().integers(10, size=(10, 10))
     a = da.from_array(x, chunks=(5, 5))
 
     assert_eq(np.delete(x, 0, axis=0), da.delete(a, 0, axis=0))
@@ -2381,7 +2401,7 @@ def _numpy_and_dask_inputs(input_sigs):
     shapes = [_shape_from_string(s) for s in input_sigs]
     chunks = [_chunks_from_string(s) for s in input_sigs]
 
-    np_inputs = [np.random.random(s) for s in shapes]
+    np_inputs = [np.random.default_rng().random(s) for s in shapes]
     da_inputs = [da.from_array(i, chunks=c) for i, c in zip(np_inputs, chunks)]
 
     return np_inputs, da_inputs
@@ -2493,10 +2513,11 @@ def test_einsum_invalid_args():
 
 
 def test_einsum_broadcasting_contraction():
-    a = np.random.rand(1, 5, 4)
-    b = np.random.rand(4, 6)
-    c = np.random.rand(5, 6)
-    d = np.random.rand(10)
+    rng = np.random.default_rng()
+    a = rng.random((1, 5, 4))
+    b = rng.random((4, 6))
+    c = rng.random((5, 6))
+    d = rng.random(10)
 
     d_a = da.from_array(a, chunks=(1, (2, 3), (2, 2)))
     d_b = da.from_array(b, chunks=((2, 2), (4, 2)))
@@ -2516,10 +2537,11 @@ def test_einsum_broadcasting_contraction():
 
 
 def test_einsum_broadcasting_contraction2():
-    a = np.random.rand(1, 1, 5, 4)
-    b = np.random.rand(4, 6)
-    c = np.random.rand(5, 6)
-    d = np.random.rand(7, 7)
+    rng = np.random.default_rng()
+    a = rng.random((1, 1, 5, 4))
+    b = rng.random((4, 6))
+    c = rng.random((5, 6))
+    d = rng.random((7, 7))
 
     d_a = da.from_array(a, chunks=(1, 1, (2, 3), (2, 2)))
     d_b = da.from_array(b, chunks=((2, 2), (4, 2)))
@@ -2539,10 +2561,11 @@ def test_einsum_broadcasting_contraction2():
 
 
 def test_einsum_broadcasting_contraction3():
-    a = np.random.rand(1, 5, 4)
-    b = np.random.rand(4, 1, 6)
-    c = np.random.rand(5, 6)
-    d = np.random.rand(7, 7)
+    rng = np.random.default_rng()
+    a = rng.random((1, 5, 4))
+    b = rng.random((4, 1, 6))
+    c = rng.random((5, 6))
+    d = rng.random((7, 7))
 
     d_a = da.from_array(a, chunks=(1, (2, 3), (2, 2)))
     d_b = da.from_array(b, chunks=((2, 2), 1, (4, 2)))
@@ -2565,17 +2588,31 @@ def test_average(a, returned):
     assert_eq(np_avg, da_avg)
 
 
-def test_average_weights():
+@pytest.mark.parametrize("a", [np.arange(11), np.arange(6).reshape((3, 2))])
+def test_average_keepdims(a):
+    d_a = da.from_array(a, chunks=2)
+
+    da_avg = da.average(d_a, keepdims=True)
+
+    if _numpy_123:
+        np_avg = np.average(a, keepdims=True)
+        assert_eq(np_avg, da_avg)
+
+
+@pytest.mark.parametrize("keepdims", [False, True])
+def test_average_weights(keepdims):
     a = np.arange(6).reshape((3, 2))
     d_a = da.from_array(a, chunks=2)
 
     weights = np.array([0.25, 0.75])
     d_weights = da.from_array(weights, chunks=2)
 
-    np_avg = np.average(a, weights=weights, axis=1)
-    da_avg = da.average(d_a, weights=d_weights, axis=1)
+    da_avg = da.average(d_a, weights=d_weights, axis=1, keepdims=keepdims)
 
-    assert_eq(np_avg, da_avg)
+    if _numpy_123:
+        assert_eq(da_avg, np.average(a, weights=weights, axis=1, keepdims=keepdims))
+    elif not keepdims:
+        assert_eq(da_avg, np.average(a, weights=weights, axis=1))
 
 
 def test_average_raises():
@@ -2597,7 +2634,7 @@ def test_iscomplexobj():
 
 
 def test_tril_triu():
-    A = np.random.randn(20, 20)
+    A = np.random.default_rng().standard_normal((20, 20))
     for chk in [5, 4]:
         dA = da.from_array(A, (chk, chk))
 
@@ -2633,13 +2670,13 @@ def test_tril_triu():
 
 
 def test_tril_ndims():
-    A = np.random.randint(0, 11, (10, 10, 10))
+    A = np.random.default_rng().integers(0, 11, (10, 10, 10))
     dA = da.from_array(A, chunks=(5, 5, 5))
     assert_eq(da.triu(dA), np.triu(A))
 
 
 def test_tril_triu_non_square_arrays():
-    A = np.random.randint(0, 11, (30, 35))
+    A = np.random.default_rng().integers(0, 11, (30, 35))
     dA = da.from_array(A, chunks=(5, 5))
     assert_eq(da.triu(dA), np.triu(A))
     assert_eq(da.tril(dA), np.tril(A))
