@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 import functools
 import itertools
@@ -88,6 +90,8 @@ def meta_from_array(x, ndim=None, dtype=None):
                 meta = meta.sum()
             else:
                 meta = meta.reshape((0,) * ndim)
+        if meta is np.ma.masked:
+            meta = np.ma.array(np.empty((0,) * ndim, dtype=dtype or x.dtype), mask=True)
     except Exception:
         meta = np.empty((0,) * ndim, dtype=dtype or x.dtype)
 
@@ -171,7 +175,10 @@ def allclose(a, b, equal_nan=False, **kwargs):
     a = normalize_to_array(a)
     b = normalize_to_array(b)
     if getattr(a, "dtype", None) != "O":
-        return np.allclose(a, b, equal_nan=equal_nan, **kwargs)
+        if hasattr(a, "mask") or hasattr(b, "mask"):
+            return np.ma.allclose(a, b, masked_equal=True, **kwargs)
+        else:
+            return np.allclose(a, b, equal_nan=equal_nan, **kwargs)
     if equal_nan:
         return a.shape == b.shape and all(
             np.isnan(b) if np.isnan(a) else a == b for (a, b) in zip(a.flat, b.flat)
@@ -205,7 +212,10 @@ def _check_dsk(dsk):
     assert not non_one, non_one
 
 
-def assert_eq_shape(a, b, check_nan=True):
+def assert_eq_shape(a, b, check_ndim=True, check_nan=True):
+    if check_ndim:
+        assert len(a) == len(b)
+
     for aa, bb in zip(a, b):
         if math.isnan(aa) or math.isnan(bb):
             if check_nan:
@@ -214,7 +224,7 @@ def assert_eq_shape(a, b, check_nan=True):
             assert aa == bb
 
 
-def _check_chunks(x, scheduler=None):
+def _check_chunks(x, check_ndim=True, scheduler=None):
     x = x.persist(scheduler=scheduler)
     for idx in itertools.product(*(range(len(c)) for c in x.chunks)):
         chunk = x.dask[(x.name,) + idx]
@@ -223,7 +233,9 @@ def _check_chunks(x, scheduler=None):
         if not hasattr(chunk, "dtype"):
             chunk = np.array(chunk, dtype="O")
         expected_shape = tuple(c[i] for c, i in zip(x.chunks, idx))
-        assert_eq_shape(expected_shape, chunk.shape, check_nan=False)
+        assert_eq_shape(
+            expected_shape, chunk.shape, check_ndim=check_ndim, check_nan=False
+        )
         assert (
             chunk.dtype == x.dtype
         ), "maybe you forgot to pass the scheduler to `assert_eq`?"
@@ -231,7 +243,12 @@ def _check_chunks(x, scheduler=None):
 
 
 def _get_dt_meta_computed(
-    x, check_shape=True, check_graph=True, check_chunks=True, scheduler=None
+    x,
+    check_shape=True,
+    check_graph=True,
+    check_chunks=True,
+    check_ndim=True,
+    scheduler=None,
 ):
     x_original = x
     x_meta = None
@@ -245,7 +262,7 @@ def _get_dt_meta_computed(
         x_meta = getattr(x, "_meta", None)
         if check_chunks:
             # Replace x with persisted version to avoid computing it twice.
-            x = _check_chunks(x, scheduler=scheduler)
+            x = _check_chunks(x, check_ndim=check_ndim, scheduler=scheduler)
         x = x.compute(scheduler=scheduler)
         x_computed = x
         if hasattr(x, "todense"):
@@ -271,6 +288,7 @@ def assert_eq(
     check_graph=True,
     check_meta=True,
     check_chunks=True,
+    check_ndim=True,
     check_type=True,
     check_dtype=True,
     equal_nan=True,
@@ -290,6 +308,7 @@ def assert_eq(
         check_shape=check_shape,
         check_graph=check_graph,
         check_chunks=check_chunks,
+        check_ndim=check_ndim,
         scheduler=scheduler,
     )
     b, bdt, b_meta, b_computed = _get_dt_meta_computed(
@@ -297,6 +316,7 @@ def assert_eq(
         check_shape=check_shape,
         check_graph=check_graph,
         check_chunks=check_chunks,
+        check_ndim=check_ndim,
         scheduler=scheduler,
     )
 
