@@ -1,7 +1,10 @@
-from .callbacks import Callback
-from timeit import default_timer
-from numbers import Number
+from __future__ import annotations
+
 import sys
+from numbers import Number
+from timeit import default_timer
+
+from dask.callbacks import Callback
 
 overhead = sys.getsizeof(1.23) * 4 + sys.getsizeof(()) * 4
 
@@ -12,19 +15,19 @@ class Cache(Callback):
     Examples
     --------
 
-    >>> cache = Cache(1e9)          # doctest: +SKIP
+    >>> cache = Cache(1e9)  # doctest: +SKIP
 
     The cache can be used locally as a context manager around ``compute`` or
     ``get`` calls:
 
-    >>> with cache:                 # doctest: +SKIP
+    >>> with cache:  # doctest: +SKIP
     ...     result = x.compute()
 
     You can also register a cache globally, so that it works for all
     computations:
 
-    >>> cache.register()            # doctest: +SKIP
-    >>> cache.unregister()          # doctest: +SKIP
+    >>> cache.register()    # doctest: +SKIP
+    >>> cache.unregister()  # doctest: +SKIP
     """
 
     def __init__(self, cache, *args, **kwargs):
