@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 import string
 import warnings
@@ -7,23 +9,25 @@ import pandas as pd
 from packaging.version import Version
 
 PANDAS_VERSION = Version(pd.__version__)
-PANDAS_GT_131 = PANDAS_VERSION >= Version("1.3.1")
-PANDAS_GT_133 = PANDAS_VERSION >= Version("1.3.3")
-PANDAS_GT_140 = PANDAS_VERSION >= Version("1.4.0")
-PANDAS_GT_150 = PANDAS_VERSION >= Version("1.5.0")
-PANDAS_GT_200 = PANDAS_VERSION.major >= 2
-PANDAS_GT_210 = PANDAS_VERSION.release >= (2, 1, 0)
+PANDAS_GE_131 = PANDAS_VERSION >= Version("1.3.1")
+PANDAS_GE_133 = PANDAS_VERSION >= Version("1.3.3")
+PANDAS_GE_140 = PANDAS_VERSION >= Version("1.4.0")
+PANDAS_GE_150 = PANDAS_VERSION >= Version("1.5.0")
+PANDAS_GE_200 = PANDAS_VERSION.major >= 2
+PANDAS_GE_201 = PANDAS_VERSION.release >= (2, 0, 1)
+PANDAS_GE_202 = PANDAS_VERSION.release >= (2, 0, 2)
+PANDAS_GE_210 = PANDAS_VERSION.release >= (2, 1, 0)
 
 import pandas.testing as tm
 
 
 def assert_categorical_equal(left, right, *args, **kwargs):
     tm.assert_extension_array_equal(left, right, *args, **kwargs)
-    assert pd.api.types.is_categorical_dtype(
-        left.dtype
+    assert isinstance(
+        left.dtype, pd.CategoricalDtype
     ), f"{left} is not categorical dtype"
-    assert pd.api.types.is_categorical_dtype(
-        right.dtype
+    assert isinstance(
+        right.dtype, pd.CategoricalDtype
     ), f"{right} is not categorical dtype"
 
 
@@ -81,8 +85,9 @@ def makeMixedDataFrame():
 
 
 @contextlib.contextmanager
-def check_numeric_only_deprecation():
-    if PANDAS_GT_150 and not PANDAS_GT_200:
+def check_numeric_only_deprecation(name=None, show_nuisance_warning: bool = False):
+    supported_funcs = ["sum", "median", "prod", "min", "max", "std", "var", "quantile"]
+    if name not in supported_funcs and PANDAS_GE_150 and not PANDAS_GE_200:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -90,13 +95,23 @@ def check_numeric_only_deprecation():
                 category=FutureWarning,
             )
             yield
+    elif (
+        not show_nuisance_warning and name not in supported_funcs and not PANDAS_GE_150
+    ):
+        with warnings.catch_warnings():
+            warnings.filterwarnings(
+                "ignore",
+                message="Dropping of nuisance columns in DataFrame",
+                category=FutureWarning,
+            )
+            yield
     else:
         yield
 
 
 @contextlib.contextmanager
 def check_nuisance_columns_warning():
-    if not PANDAS_GT_150:
+    if not PANDAS_GE_150:
         with warnings.catch_warnings(record=True):
             warnings.filterwarnings(
                 "ignore", "Dropping of nuisance columns", FutureWarning
@@ -108,7 +123,7 @@ def check_nuisance_columns_warning():
 
 @contextlib.contextmanager
 def check_groupby_axis_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -122,7 +137,7 @@ def check_groupby_axis_deprecation():
 
 @contextlib.contextmanager
 def check_observed_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -136,7 +151,7 @@ def check_observed_deprecation():
 
 @contextlib.contextmanager
 def check_axis_keyword_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -150,7 +165,7 @@ def check_axis_keyword_deprecation():
 
 @contextlib.contextmanager
 def check_convert_dtype_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -164,7 +179,7 @@ def check_convert_dtype_deprecation():
 
 @contextlib.contextmanager
 def check_to_pydatetime_deprecation(catch_deprecation_warnings: bool):
-    if PANDAS_GT_210 and catch_deprecation_warnings:
+    if PANDAS_GE_210 and catch_deprecation_warnings:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -178,7 +193,7 @@ def check_to_pydatetime_deprecation(catch_deprecation_warnings: bool):
 
 @contextlib.contextmanager
 def check_apply_dataframe_deprecation():
-    if PANDAS_GT_210:
+    if PANDAS_GE_210:
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
@@ -190,7 +205,35 @@ def check_apply_dataframe_deprecation():
         yield
 
 
-if PANDAS_GT_150:
+@contextlib.contextmanager
+def check_applymap_dataframe_deprecation():
+    if PANDAS_GE_210:
+        with warnings.catch_warnings():
+            warnings.filterwarnings(
+                "ignore",
+                message="DataFrame.applymap has been deprecated",
+                category=FutureWarning,
+            )
+            yield
+    else:
+        yield
+
+
+@contextlib.contextmanager
+def check_reductions_runtime_warning():
+    if PANDAS_GE_200 and not PANDAS_GE_201:
+        with warnings.catch_warnings():
+            warnings.filterwarnings(
+                "ignore",
+                message="invalid value encountered in double_scalars|Degrees of freedom <= 0 for slice",
+                category=RuntimeWarning,
+            )
+            yield
+    else:
+        yield
+
+
+if PANDAS_GE_150:
     IndexingError = pd.errors.IndexingError
 else:
     IndexingError = pd.core.indexing.IndexingError
@@ -198,7 +241,7 @@ else:
 
 def is_any_real_numeric_dtype(arr_or_dtype) -> bool:
     try:
-        # `is_any_real_numeric_dtype` was added in PANDAS_GT_200.
+        # `is_any_real_numeric_dtype` was added in PANDAS_GE_200.
         # We can remove this compatibility utility once we only support `pandas>=2.0`
         return pd.api.types.is_any_real_numeric_dtype(arr_or_dtype)
     except AttributeError:
@@ -209,3 +252,16 @@ def is_any_real_numeric_dtype(arr_or_dtype) -> bool:
             and not is_complex_dtype(arr_or_dtype)
             and not is_bool_dtype(arr_or_dtype)
         )
+
+
+def is_string_dtype(arr_or_dtype) -> bool:
+    # is_string_dtype did not recognize pyarrow strings before 2.0
+    # Can remove once 2.0 is minimum version for us
+    if hasattr(arr_or_dtype, "dtype"):
+        dtype = arr_or_dtype.dtype
+    else:
+        dtype = arr_or_dtype
+
+    if not PANDAS_GE_200:
+        return pd.api.types.is_dtype_equal(dtype, "string")
+    return pd.api.types.is_string_dtype(dtype)
