@@ -616,7 +616,7 @@ def read_parquet(
     # to be more fault tolerant, as transient transport errors can occur.
     # The specific number 5 isn't hugely motivated: it's less than ten and more
     # than two.
-    annotations = dask.config.get("annotations", {})
+    annotations = dask.get_annotations()
     if "retries" not in annotations and not _is_local_fs(fs):
         ctx = dask.annotate(retries=5)
     else:
@@ -630,7 +630,9 @@ def read_parquet(
             meta=meta,
             divisions=divisions,
             label="read-parquet",
-            token=tokenize(path, **input_kwargs),
+            token=tokenize(
+                path, dask.config.get("dataframe.convert-string"), **input_kwargs
+            ),
             enforce_metadata=False,
             creation_info={
                 "func": read_parquet,
@@ -992,7 +994,7 @@ def to_parquet(
     # to be more fault tolerant, as transient transport errors can occur.
     # The specific number 5 isn't hugely motivated: it's less than ten and more
     # than two.
-    annotations = dask.config.get("annotations", {})
+    annotations = dask.get_annotations()
     if "retries" not in annotations and not _is_local_fs(fs):
         ctx = dask.annotate(retries=5)
     else:
@@ -1347,9 +1349,31 @@ def apply_filters(parts, statistics, filters):
     parts, statistics: the same as the input, but possibly a subset
     """
 
+    # Supported predicate operators
+    _supported_operators = {
+        "=",
+        "==",
+        "!=",
+        "<",
+        "<=",
+        ">",
+        ">=",
+        "is",
+        "is not",
+        "in",
+        "not in",
+    }
+
     def apply_conjunction(parts, statistics, conjunction):
         for column, operator, value in conjunction:
-            if operator == "in" and not isinstance(value, (list, set, tuple)):
+            if operator not in _supported_operators:
+                # Use same error message as `_filters_to_expression`
+                raise ValueError(
+                    f'"{(column, operator, value)}" is not a valid operator in predicates.'
+                )
+            elif operator in ("in", "not in") and not isinstance(
+                value, (list, set, tuple)
+            ):
                 raise TypeError("Value of 'in' filter must be a list, set, or tuple.")
             out_parts = []
             out_statistics = []
@@ -1394,6 +1418,8 @@ def apply_filters(parts, statistics, filters):
                         and max >= value
                         or operator == "in"
                         and any(min <= item <= max for item in value)
+                        or operator == "not in"
+                        and not any(min == max == item for item in value)
                     ):
                         out_parts.append(part)
                         out_statistics.append(stats)
