@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from datetime import datetime
 
 import numpy as np
@@ -9,7 +11,7 @@ import dask.array as da
 import dask.dataframe as dd
 from dask import config
 from dask.blockwise import Blockwise
-from dask.dataframe._compat import PANDAS_GT_200, tm
+from dask.dataframe._compat import PANDAS_GE_200, tm
 from dask.dataframe.io.io import _meta_from_array
 from dask.dataframe.optimize import optimize
 from dask.dataframe.utils import assert_eq, get_string_dtype, pyarrow_strings_enabled
@@ -278,7 +280,7 @@ def test_from_pandas_npartitions_duplicates(index):
 
 
 @pytest.mark.skipif(
-    not PANDAS_GT_200, reason="dataframe.convert-string requires pandas>=2.0"
+    not PANDAS_GE_200, reason="dataframe.convert-string requires pandas>=2.0"
 )
 def test_from_pandas_convert_string_config():
     pytest.importorskip("pyarrow", reason="Requires pyarrow strings")
@@ -315,7 +317,7 @@ def test_from_pandas_convert_string_config():
     assert_eq(df_pyarrow, ddf)
 
 
-@pytest.mark.skipif(PANDAS_GT_200, reason="Requires pandas<2.0")
+@pytest.mark.skipif(PANDAS_GE_200, reason="Requires pandas<2.0")
 def test_from_pandas_convert_string_config_raises():
     pytest.importorskip("pyarrow", reason="Different error without pyarrow")
     df = pd.DataFrame(
@@ -333,6 +335,16 @@ def test_from_pandas_convert_string_config_raises():
             dd.from_pandas(df, npartitions=2)
 
 
+@pytest.mark.parametrize("index", [[1, 2, 3], [3, 2, 1]])
+@pytest.mark.parametrize("sort", [True, False])
+def test_from_pandas_immutable(sort, index):
+    pdf = pd.DataFrame({"a": [1, 2, 3]}, index=index)
+    expected = pdf.copy()
+    df = dd.from_pandas(pdf, npartitions=2, sort=sort)
+    pdf.iloc[0, 0] = 100
+    assert_eq(df, expected)
+
+
 @pytest.mark.gpu
 def test_gpu_from_pandas_npartitions_duplicates():
     cudf = pytest.importorskip("cudf")
