@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import warnings
 from functools import partial
 
@@ -7,9 +9,11 @@ from pandas.api.types import is_extension_array_dtype
 from tlz import partition
 
 from dask.dataframe._compat import (
-    PANDAS_GT_131,
-    PANDAS_GT_200,
+    PANDAS_GE_131,
+    PANDAS_GE_140,
+    PANDAS_GE_200,
     check_apply_dataframe_deprecation,
+    check_applymap_dataframe_deprecation,
     check_convert_dtype_deprecation,
     check_observed_deprecation,
 )
@@ -57,6 +61,11 @@ def apply(df, *args, **kwargs):
             return df.apply(*args, **kwargs)
 
 
+def applymap(df, *args, **kwargs):
+    with check_applymap_dataframe_deprecation():
+        return df.applymap(*args, **kwargs)
+
+
 def try_loc(df, iindexer, cindexer=None):
     """
     .loc for unknown divisions
@@ -102,7 +111,7 @@ def boundary_slice(df, start, stop, right_boundary=True, left_boundary=True, kin
     if len(df.index) == 0:
         return df
 
-    if PANDAS_GT_131:
+    if PANDAS_GE_131:
         if kind is not None:
             warnings.warn(
                 "The `kind` argument is no longer used/supported. "
@@ -257,7 +266,7 @@ def describe_nonnumeric_aggregate(stats, name):
         data = [0, 0]
         index = ["count", "unique"]
         dtype = None
-        data.extend([None, None])
+        data.extend([np.nan, np.nan])
         index.extend(["top", "freq"])
         dtype = object
         result = pd.Series(data, index=index, dtype=dtype, name=name)
@@ -340,8 +349,9 @@ def cummax_aggregate(x, y):
 def assign(df, *pairs):
     # Only deep copy when updating an element
     # (to avoid modifying the original)
+    # Setitem never modifies an array inplace with pandas 1.4 and up
     pairs = dict(partition(2, pairs))
-    deep = bool(set(pairs) & set(df.columns))
+    deep = bool(set(pairs) & set(df.columns)) and not PANDAS_GE_140
     df = df.copy(deep=bool(deep))
     for name, val in pairs.items():
         df[name] = val
@@ -371,7 +381,7 @@ def value_counts_aggregate(
         out /= total_length if total_length is not None else out.sum()
     if sort:
         out = out.sort_values(ascending=ascending)
-    if PANDAS_GT_200 and normalize:
+    if PANDAS_GE_200 and normalize:
         out.name = "proportion"
     return out
 
@@ -405,7 +415,10 @@ def drop_columns(df, columns, dtype):
 
 
 def fillna_check(df, method, check=True):
-    out = df.fillna(method=method)
+    if method:
+        out = getattr(df, method)()
+    else:
+        out = df.fillna()
     if check and out.isnull().values.all(axis=0).any():
         raise ValueError(
             "All NaN partition encountered in `fillna`. Try "
