@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import math
 import numbers
 import uuid
@@ -754,9 +756,9 @@ def fuse(
                     children_info = info_stack[-num_children:]
                     del info_stack[-num_children:]
                     for (
-                        cur_key,
-                        cur_task,
-                        cur_keys,
+                        _,
+                        _,
+                        _,
                         cur_height,
                         cur_width,
                         cur_num_nodes,
