@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 r""" Static order of nodes in dask graph
 
 Dask makes decisions on what tasks to prioritize both
@@ -75,11 +77,10 @@ Work towards *small goals* with *big steps*.
     This relies on the regularity of graph constructors like dask.array to be a
     good proxy for ordering.  This is usually a good idea and a sane default.
 """
-from collections import defaultdict
+from collections import defaultdict, namedtuple
 from math import log
 
-from .core import get_dependencies, get_deps, getcycle, reverse_dict  # noqa: F401
-from .utils_test import add, inc  # noqa: F401
+from dask.core import get_dependencies, get_deps, getcycle, reverse_dict
 
 
 def order(dsk, dependencies=None):
@@ -101,6 +102,8 @@ def order(dsk, dependencies=None):
 
     Examples
     --------
+    >>> inc = lambda x: x + 1
+    >>> add = lambda x, y: x + y
     >>> dsk = {'a': 1, 'b': 2, 'c': (inc, 'a'), 'd': (add, 'b', 'c')}
     >>> order(dsk)
     {'a': 0, 'c': 1, 'b': 2, 'd': 3}
@@ -865,6 +868,7 @@ def graph_metrics(dependencies, dependents, total_dependencies):
 
     Examples
     --------
+    >>> inc = lambda x: x + 1
     >>> dsk = {'a1': 1, 'b1': (inc, 'a1'), 'b2': (inc, 'a1'), 'c1': (inc, 'b1')}
     >>> dependencies, dependents = get_deps(dsk)
     >>> _, total_dependencies = ndependencies(dependencies, dependents)
@@ -939,6 +943,7 @@ def ndependencies(dependencies, dependents):
 
     Examples
     --------
+    >>> inc = lambda x: x + 1
     >>> dsk = {'a': 1, 'b': (inc, 'a'), 'c': (inc, 'b')}
     >>> dependencies, dependents = get_deps(dsk)
     >>> num_dependencies, total_dependencies = ndependencies(dependencies, dependents)
@@ -1004,3 +1009,70 @@ class StrComparable:
             return self.obj < other.obj
         except Exception:
             return str(self.obj) < str(other.obj)
+
+
+OrderInfo = namedtuple(
+    "OrderInfo",
+    (
+        "order",
+        "age",
+        "num_data_when_run",
+        "num_data_when_released",
+        "num_dependencies_freed",
+    ),
+)
+
+
+def diagnostics(dsk, o=None, dependencies=None):
+    """Simulate runtime metrics as though running tasks one at a time in order.
+
+    These diagnostics can help reveal behaviors of and issues with ``order``.
+
+    Returns a dict of `namedtuple("OrderInfo")` and a list of the number of outputs held over time.
+
+    OrderInfo fields:
+    - order : the order in which the node is run.
+    - age : how long the output of a node is held.
+    - num_data_when_run : the number of outputs held in memory when a node is run.
+    - num_data_when_released : the number of outputs held in memory when the output is released.
+    - num_dependencies_freed : the number of dependencies freed by running the node.
+    """
+    if dependencies is None:
+        dependencies, dependents = get_deps(dsk)
+    else:
+        dependents = reverse_dict(dependencies)
+    if o is None:
+        o = order(dsk, dependencies=dependencies)
+
+    pressure = []
+    num_in_memory = 0
+    age = {}
+    runpressure = {}
+    releasepressure = {}
+    freed = {}
+    num_needed = {key: len(val) for key, val in dependents.items()}
+    for i, key in enumerate(sorted(dsk, key=o.__getitem__)):
+        pressure.append(num_in_memory)
+        runpressure[key] = num_in_memory
+        released = 0
+        for dep in dependencies[key]:
+            num_needed[dep] -= 1
+            if num_needed[dep] == 0:
+                age[dep] = i - o[dep]
+                releasepressure[dep] = num_in_memory
+                released += 1
+        freed[key] = released
+        if dependents[key]:
+            num_in_memory -= released - 1
+        else:
+            age[key] = 0
+            releasepressure[key] = num_in_memory
+            num_in_memory -= released
+
+    rv = {
+        key: OrderInfo(
+            val, age[key], runpressure[key], releasepressure[key], freed[key]
+        )
+        for key, val in o.items()
+    }
+    return rv, pressure
