@@ -1,13 +1,16 @@
+from __future__ import annotations
+
 import pickle
 from collections import namedtuple
 
 import pytest
 
-from dask import core
 from dask.core import (
     flatten,
+    get,
     get_dependencies,
     get_deps,
+    getcycle,
     has_tasks,
     istask,
     literal,
@@ -64,7 +67,7 @@ def test_preorder_traversal():
 
 
 class TestGet(GetFunctionTestMixin):
-    get = staticmethod(core.get)
+    get = staticmethod(get)
 
 
 def test_GetFunctionTestMixin_class():
@@ -75,7 +78,7 @@ def test_GetFunctionTestMixin_class():
     pytest.raises(AssertionError, custom_testget.test_get)
 
     class TestCustomGetPass(GetFunctionTestMixin):
-        get = staticmethod(core.get)
+        get = staticmethod(get)
 
     custom_testget = TestCustomGetPass()
     custom_testget.test_get()
@@ -84,7 +87,7 @@ def test_GetFunctionTestMixin_class():
 def test_get_dependencies_nested():
     dsk = {"x": 1, "y": 2, "z": (add, (inc, [["x"]]), "y")}
 
-    assert get_dependencies(dsk, "z") == set(["x", "y"])
+    assert get_dependencies(dsk, "z") == {"x", "y"}
     assert sorted(get_dependencies(dsk, "z", as_list=True)) == ["x", "y"]
 
 
@@ -96,13 +99,13 @@ def test_get_dependencies_empty():
 
 def test_get_dependencies_list():
     dsk = {"x": 1, "y": 2, "z": ["x", [(inc, "y")]]}
-    assert get_dependencies(dsk, "z") == set(["x", "y"])
+    assert get_dependencies(dsk, "z") == {"x", "y"}
     assert sorted(get_dependencies(dsk, "z", as_list=True)) == ["x", "y"]
 
 
 def test_get_dependencies_task():
     dsk = {"x": 1, "y": 2, "z": ["x", [(inc, "y")]]}
-    assert get_dependencies(dsk, task=(inc, "x")) == set(["x"])
+    assert get_dependencies(dsk, task=(inc, "x")) == {"x"}
     assert get_dependencies(dsk, task=(inc, "x"), as_list=True) == ["x"]
 
 
@@ -245,9 +248,38 @@ def test_quote():
     literals = [[1, 2, 3], (add, 1, 2), [1, [2, 3]], (add, 1, (add, 2, 3)), {"x": "x"}]
 
     for l in literals:
-        assert core.get({"x": quote(l)}, "x") == l
+        assert get({"x": quote(l)}, "x") == l
 
 
 def test_literal_serializable():
     l = literal((add, 1, 2))
     assert pickle.loads(pickle.dumps(l)).data == (add, 1, 2)
+
+
+def test_getcycle():
+    dsk = {
+        0: [7, 13, 7, 9, 13, 3, 9, 18, 18, 17],
+        1: [14, 14, 12, 1, 9, 16, 4, 5, 9, 8],
+        2: [3, 1, 7, 7, 2, 0, 0, 6, 3, 2],
+        3: [4, 8, 3, 14, 15, 19, 14, 1, 9, 1],
+        4: [9, 13, 19, 4, 16, 8, 11, 1, 16, 1],
+        5: [9, 8, 12, 13, 10, 13, 19, 3, 18, 18],
+        6: [10, 2, 13, 16, 3, 12, 7, 16, 5, 17],
+        7: [16, 8, 6, 4, 4, 10, 3, 1, 13, 10],
+        8: [11, 4, 12, 10, 14, 6, 18, 15, 16, 12],
+        9: [17, 18, 5, 16, 19, 16, 3, 6, 16, 18],
+    }
+    assert len(getcycle(dsk, list(dsk))) <= 3  # 7->6->7
+    dsk = {
+        0: [1, 27, 6, 25, 30, 16, 1, 1, 35, 17],
+        1: [35, 22, 21, 31, 2, 28, 36, 0, 29, 29],
+        2: [14, 27, 10, 1, 38, 18, 28, 28, 6, 0],
+        3: [0, 37, 7, 16, 38, 28, 34, 13, 30, 10],
+        4: [22, 22, 27, 13, 29, 36, 22, 9, 39, 19],
+        5: [38, 7, 18, 17, 33, 5, 29, 11, 23, 30],
+        6: [3, 30, 28, 38, 4, 13, 14, 27, 29, 38],
+        7: [22, 27, 12, 2, 22, 16, 34, 15, 18, 16],
+        8: [36, 21, 24, 22, 28, 38, 21, 2, 4, 24],
+        9: [38, 32, 38, 7, 31, 34, 39, 20, 30, 18],
+    }
+    assert len(getcycle(dsk, list(dsk))) <= 4  # 0->1->2->0
