@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 import pytest
 
 import dask
 from dask.core import get_deps
-from dask.order import ndependencies, order
+from dask.order import diagnostics, ndependencies, order
 from dask.utils_test import add, inc
 
 
@@ -980,3 +982,88 @@ def test_eager_to_compute_dependent_to_free_parent():
     # Allow one to be bad, b/c this is hard!
     costs = sorted(cost_of_pairs.values())
     assert sum(costs[:-1]) <= 25 or sum(costs) <= 31
+
+
+def test_diagnostics(abcde):
+    r"""
+        a1  b1  c2  d1  e1
+        /|\ /|\ /|\ /|  /
+       / | X | X | X | /
+      /  |/ \|/ \|/ \|/
+    a0  b0  c0  d0  e0
+    """
+    a, b, c, d, e = abcde
+    dsk = {
+        (a, 0): (f,),
+        (b, 0): (f,),
+        (c, 0): (f,),
+        (d, 0): (f,),
+        (e, 0): (f,),
+        (a, 1): (f, (a, 0), (b, 0), (c, 0)),
+        (b, 1): (f, (b, 0), (c, 0), (d, 0)),
+        (c, 1): (f, (c, 0), (d, 0), (e, 0)),
+        (d, 1): (f, (d, 0), (e, 0)),
+        (e, 1): (f, (e, 0)),
+    }
+    info, memory_over_time = diagnostics(dsk)
+    assert memory_over_time == [0, 1, 2, 3, 2, 3, 2, 3, 2, 1]
+    assert {key: val.order for key, val in info.items()} == {
+        (a, 0): 0,
+        (b, 0): 1,
+        (c, 0): 2,
+        (d, 0): 4,
+        (e, 0): 6,
+        (a, 1): 3,
+        (b, 1): 5,
+        (c, 1): 7,
+        (d, 1): 8,
+        (e, 1): 9,
+    }
+    assert {key: val.age for key, val in info.items()} == {
+        (a, 0): 3,
+        (b, 0): 4,
+        (c, 0): 5,
+        (d, 0): 4,
+        (e, 0): 3,
+        (a, 1): 0,
+        (b, 1): 0,
+        (c, 1): 0,
+        (d, 1): 0,
+        (e, 1): 0,
+    }
+    assert {key: val.num_dependencies_freed for key, val in info.items()} == {
+        (a, 0): 0,
+        (b, 0): 0,
+        (c, 0): 0,
+        (d, 0): 0,
+        (e, 0): 0,
+        (a, 1): 1,
+        (b, 1): 1,
+        (c, 1): 1,
+        (d, 1): 1,
+        (e, 1): 1,
+    }
+    assert {key: val.num_data_when_run for key, val in info.items()} == {
+        (a, 0): 0,
+        (b, 0): 1,
+        (c, 0): 2,
+        (d, 0): 2,
+        (e, 0): 2,
+        (a, 1): 3,
+        (b, 1): 3,
+        (c, 1): 3,
+        (d, 1): 2,
+        (e, 1): 1,
+    }
+    assert {key: val.num_data_when_released for key, val in info.items()} == {
+        (a, 0): 3,
+        (b, 0): 3,
+        (c, 0): 3,
+        (d, 0): 2,
+        (e, 0): 1,
+        (a, 1): 3,
+        (b, 1): 3,
+        (c, 1): 3,
+        (d, 1): 2,
+        (e, 1): 1,
+    }
