@@ -10,6 +10,7 @@ import multiprocessing.pool
 import sys
 import threading
 from collections import defaultdict
+from collections.abc import Hashable, Mapping, Sequence
 from concurrent.futures import Executor, ThreadPoolExecutor
 from threading import Lock, current_thread
 
@@ -32,7 +33,14 @@ def pack_exception(e, dumps):
     return e, sys.exc_info()[2]
 
 
-def get(dsk, result, cache=None, num_workers=None, pool=None, **kwargs):
+def get(
+    dsk: Mapping,
+    keys: Sequence[Hashable] | Hashable,
+    cache=None,
+    num_workers=None,
+    pool=None,
+    **kwargs,
+):
     """Threaded cached implementation of dask.get
 
     Parameters
@@ -40,7 +48,7 @@ def get(dsk, result, cache=None, num_workers=None, pool=None, **kwargs):
 
     dsk: dict
         A dask dictionary specifying a workflow
-    result: key or list of keys
+    keys: key or list of keys
         Keys corresponding to desired data
     num_workers: integer of thread count
         The number of threads to use in the ThreadPool that will actually execute tasks
@@ -82,7 +90,7 @@ def get(dsk, result, cache=None, num_workers=None, pool=None, **kwargs):
         pool.submit,
         pool._max_workers,
         dsk,
-        result,
+        keys,
         cache=cache,
         get_id=_thread_get_id,
         pack_exception=pack_exception,
